HiveStoragePlugin class final

Inheritance
  • Object
  • Plugin
  • StoragePlugin
  • HiveStoragePlugin
Mixed-in types
  • InitOncePlugin

Constructors

HiveStoragePlugin({String boxName = 'vyuh_storage'})
Creates a new HiveStoragePlugin instance.

Properties

boxName → String
final
hashCode → int
The hash code for this object.
no setterinherited
initialized → bool
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
finalinherited

Methods

delete(String key) → Future<bool>
Deletes a value from storage by its key.
override
dispose() → Future<void>
inherited
disposeOnce() → Future<void>
override
has(String key) → Future<bool>
Checks if a key exists in storage.
override
init() → Future<void>
inherited
initOnce() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String key) → Future
Reads a value from the box with the given key.
override
toString() → String
A string representation of this object.
inherited
write(String key, dynamic value) → Future
Writes a value to storage with the given key.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited