write method
Writes a value to storage with the given key.
Supported values and conversion rules depend on the selected implementation.
Implementation
@override
Future<dynamic> write(String key, dynamic value) async {
await _box.put(key, value);
return value;
}